@@ -1,5 +1,5 @@
 /* info-utils.c -- miscellanous.
-   $Id: info-utils.c 6136 2015-02-21 12:35:38Z gavin $
+   $Id: info-utils.c 6184 2015-03-09 19:08:16Z gavin $
 
    Copyright 1993, 1998, 2003, 2004, 2007, 2008, 2009, 2011, 2012,
    2013, 2014, 2015 Free Software Foundation, Inc.
@@ -1123,27 +1123,33 @@ parse_top_node_line (NODE *node)
       skip_input (skip_whitespace (inptr));
 
       /* Check what field we are looking at */
-      if (!strncmp (inptr, INFO_FILE_LABEL, strlen(INFO_FILE_LABEL)))
+      if (!strncasecmp (inptr, INFO_FILE_LABEL, strlen(INFO_FILE_LABEL)))
         {
           skip_input (strlen(INFO_FILE_LABEL));
           store_in = &dummy;
         }
-      else if (!strncmp (inptr, INFO_NODE_LABEL, strlen(INFO_NODE_LABEL)))
+      else if (!strncasecmp (inptr, INFO_NODE_LABEL, strlen(INFO_NODE_LABEL)))
         {
           skip_input (strlen(INFO_NODE_LABEL));
           store_in = &dummy;
         }
-      else if (!strncmp (inptr, INFO_PREV_LABEL, strlen(INFO_PREV_LABEL)))
+      else if (!strncasecmp (inptr, INFO_PREV_LABEL, strlen(INFO_PREV_LABEL)))
         {
           skip_input (strlen(INFO_PREV_LABEL));
           store_in = &node->prev;
         }
-      else if (!strncmp (inptr, INFO_NEXT_LABEL, strlen(INFO_NEXT_LABEL)))
+      else if (!strncasecmp (inptr, INFO_ALTPREV_LABEL, 
+                             strlen(INFO_ALTPREV_LABEL)))
+        {
+          skip_input (strlen(INFO_ALTPREV_LABEL));
+          store_in = &node->prev;
+        }
+      else if (!strncasecmp (inptr, INFO_NEXT_LABEL, strlen(INFO_NEXT_LABEL)))
         {
           skip_input (strlen(INFO_NEXT_LABEL));
           store_in = &node->next;
         }
-      else if (!strncmp (inptr, INFO_UP_LABEL, strlen(INFO_UP_LABEL)))
+      else if (!strncasecmp (inptr, INFO_UP_LABEL, strlen(INFO_UP_LABEL)))
         {
           skip_input (strlen(INFO_UP_LABEL));
           store_in = &node->up;
@@ -1479,10 +1485,11 @@ scan_reference_target (REFERENCE *entry, NODE *node, int in_parentheses)
 
       length = skip_whitespace (inptr);
       length += read_bracketed_filename (inptr + length, &entry->filename);
-      length += skip_whitespace (inptr + length);
+      length += strspn (inptr + length, " ");
 
       /* Get the node name. */
-      length += read_quoted_string (inptr + length, ",.", 2, &entry->nodename);
+      length += read_quoted_string (inptr + length, ",.\t\n", 2, 
+                                    &entry->nodename);
       if (inptr[length] == '.') /* A '.' terminating the entry. */
         length++;
 
