@@ -1,5 +1,5 @@
 /* info.c -- Display nodes of Info files in multiple windows.
-   $Id: info.c 6075 2015-01-29 12:45:19Z gavin $
+   $Id: info.c 6209 2015-04-07 10:52:27Z gavin $
 
    Copyright 1993, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003,
    2004, 2005, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015
@@ -287,32 +287,91 @@ add_initial_nodes (int argc, char **argv, char **error)
       if (user_nodenames_index > 0 && ref_index > 0)
         {
           info_reference_free (ref_list[0]);
+          ref_list[0] = 0;
           ref_index = 0;
         }
 
       for (i = 0; user_nodenames[i]; i++)
         {
-          char *node_filename;
+          char *node_filename = 0;
+          char *node_nodename = 0;
 
           /* Parse node spec to support invoking
              like info --node "(emacs)Buffers". */
           info_parse_node (user_nodenames[i]);
           if (info_parsed_filename)
-            node_filename = info_parsed_filename;
+            {
+              node_filename = info_parsed_filename;
+              node_nodename = info_parsed_nodename;
+            }
           else
             {
+              FILE_BUFFER *file_buffer;
+              TAG *tag;
+              int j;
+
               if (!initial_file)
                 {
+                  free (*error);
                   asprintf (error, _("No file given for node '%s'."),
                             user_nodenames[i]);
                   continue;
                 }
+
+              /* Check for a node by this name, and if there isn't one
+                 look for an inexact match. */
+
               node_filename = initial_file;
+              node_nodename = 0;
+
+              file_buffer = info_find_file (node_filename);
+
+              /* First look for an exact match. */
+              for (j = 0; (tag = file_buffer->tags[j]); j++)
+                if (strcmp (user_nodenames[i], tag->nodename) == 0)
+                  {
+                    node_nodename = tag->nodename;
+                    break;
+                  }
+
+              if (!node_nodename)
+                {
+                  int best_guess = -1;
+                  int len = strlen (user_nodenames[i]);
+                  for (j = 0; (tag = file_buffer->tags[j]); j++)
+                    {
+                      if (mbscasecmp (user_nodenames[i], tag->nodename) == 0)
+                        {
+                          /* Exact, case-insensitive match. */
+                          node_nodename = tag->nodename;
+                          best_guess = -1;
+                          break;
+                        }
+                      else if (best_guess == -1
+                               && (mbsncasecmp (user_nodenames[i],
+                                                tag->nodename, len) == 0))
+                        /* Case-insensitive initial substring. */
+                        best_guess = j;
+                    }
+                  if (best_guess != -1)
+                    {
+                      node_nodename = file_buffer->tags[best_guess]->nodename;
+                    }
+                }
+
+              if (!node_nodename)
+                {
+                  free (*error);
+                  asprintf (error, _("Cannot find node '%s'."),
+                            user_nodenames[i]);
+                  continue;
+                }
             }
 
-          add_pointer_to_array
-            (info_new_reference (node_filename, info_parsed_nodename),
-             ref_index, ref_list, ref_slots, 2);
+          if (node_filename && node_nodename)
+            add_pointer_to_array
+              (info_new_reference (node_filename, node_nodename),
+               ref_index, ref_list, ref_slots, 2);
         }
     }
 
@@ -383,13 +442,55 @@ add_initial_nodes (int argc, char **argv, char **error)
       else if (argc == 1 && argv[0])
         {
           FILE_BUFFER *fb;
-          REFERENCE *nearest;
+          REFERENCE *match;
 
           debug (3, ("looking in indices"));
           fb = info_find_file (ref_list[0]->filename);
           if (fb)
             {
-              nearest = look_in_indices (fb, argv[0]);
+              match = look_in_indices (fb, argv[0], 0);
+              if (match)
+                {
+                  argv += argc; argc = 0;
+                  free (*error); *error = 0;
+
+                  info_reference_free (ref_list[0]);
+                  ref_list[0] = info_copy_reference (match);
+                }
+            }
+        }
+
+      /* If there are arguments remaining, follow menus inexactly. */
+      if (argc != 0)
+        {
+          initial_node = info_get_node_with_defaults (ref_list[0]->filename,
+                                                      ref_list[0]->nodename,
+                                                      0);
+          free (*error); *error = 0;
+          node_via_menus = info_follow_menus (initial_node, argv, error, 0);
+          if (node_via_menus && (argc >= 2 || !*error))
+            {
+              argv += argc; argc = 0;
+
+              info_reference_free (ref_list[0]);
+              ref_list[0] = info_new_reference (node_via_menus->fullpath,
+                                                node_via_menus->nodename);
+              free_history_node (node_via_menus);
+            }
+        }
+
+      /* If still no nodes found, and there is exactly one argument remaining,
+         look in indices sloppily. */
+      if (argc == 1)
+        {
+          FILE_BUFFER *fb;
+          REFERENCE *nearest;
+
+          debug (3, ("looking in indices sloppily"));
+          fb = info_find_file (ref_list[0]->filename);
+          if (fb)
+            {
+              nearest = look_in_indices (fb, argv[0], 1);
               if (nearest)
                 {
                   argv += argc; argc = 0;
@@ -400,25 +501,6 @@ add_initial_nodes (int argc, char **argv, char **error)
                 }
             }
         }
-
-      /* If there are arguments remaining, follow menus
-         inexactly. */
-      if (argc != 0)
-        {
-          initial_node = info_get_node_with_defaults (ref_list[0]->filename,
-                                                      ref_list[0]->nodename,
-                                                      0);
-          node_via_menus = info_follow_menus (initial_node, argv, error, 0);
-          if (node_via_menus)
-            {
-              argv += argc; argc = 0;
-
-              info_reference_free (ref_list[0]);
-              ref_list[0] = info_new_reference (node_via_menus->fullpath,
-                                                node_via_menus->nodename);
-              free_history_node (node_via_menus);
-            }
-        }
     }
 
   return;
