@@ -1,5 +1,5 @@
 /* man.c: How to read and format man files.
-   $Id: man.c 6011 2014-12-30 21:54:02Z gavin $
+   $Id: man.c 6182 2015-03-07 19:36:01Z gavin $
 
    Copyright 1995, 1997, 1998, 1999, 2000, 2002, 2003, 2004, 2005, 
    2007, 2008, 2009, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
@@ -90,7 +90,6 @@ get_manpage_node (char *pagename)
   /* Node wasn't found, or its contents were freed since last time. */
   if (!node->contents)
     {
-      char header[1024];
       int hlen, plen;
 
       page = get_manpage_contents (pagename);
@@ -100,11 +99,11 @@ get_manpage_node (char *pagename)
 
       if (!preprocess_nodes_p)
         {
-          sprintf (header, "%s %s,  %s %s,  %s (dir)\n\n",
+          char *header;
+          hlen = asprintf (&header, "%s %s,  %s %s,  %s (dir)\n\n",
                    INFO_FILE_LABEL, MANPAGE_FILE_BUFFER_NAME,
                    INFO_NODE_LABEL, pagename,
                    INFO_UP_LABEL);
-          hlen = strlen (header);
 
           node->contents = xcalloc (1, hlen + plen + 1);
           memcpy (node->contents, header, hlen);
@@ -113,6 +112,7 @@ get_manpage_node (char *pagename)
           /* Set nodelen. */
           node->nodelen = hlen + plen;
 
+          free (header);
           /* FIXME: Don't allocate page just to immediately free it. */
           free (page);
         }
@@ -323,6 +323,7 @@ get_manpage_from_formatter (char *formatter_args[])
   char *formatted_page = NULL;
   int pipes[2];
   pid_t child;
+  int formatter_status = 0;
 
   /* Open a pipe to this program, read the output, and save it away
      in FORMATTED_PAGE.  The reader end of the pipe is pipes[0]; the
@@ -341,7 +342,7 @@ get_manpage_from_formatter (char *formatter_args[])
       close (pipes[1]);
       formatted_page = read_from_fd (pipes[0]);
       close (pipes[0]);
-      wait (NULL); /* Wait for child process to exit. */
+      wait (&formatter_status); /* Wait for child process to exit. */
     }
   else
     { /* In the child, close the read end of the pipe, make the write end
@@ -387,18 +388,36 @@ get_manpage_from_formatter (char *formatter_args[])
     if (fpipe == 0)
       return NULL;
     formatted_page = read_from_fd (fileno (fpipe));
-    if (pclose (fpipe) == -1)
-      {
-	if (formatted_page)
-	  free (formatted_page);
-	return NULL;
-      }
+    formatter_status = pclose (fpipe);
   }
 #endif /* !PIPE_USE_FORK */
 
+  if (!formatted_page)
+    return 0;
+
+  if (formatter_status != 0) /* Check for failure. */
+    {
+      int i;
+      char *p;
+      /* It is possible for "man -a" to output a man page and still to exit 
+         with a non-zero status.  This was found to happen when duplicate man 
+         pages were found.  Hence, still treat it as a success if more than 
+         three lines were output.  (A small amount of output could be error 
+         messages that were sent to standard output.) */
+      p = formatted_page;
+      for (i = 0; i < 3; i++)
+        {
+          p = strchr (p, '\n');
+          if (!p)
+            {
+              free (formatted_page);
+              return NULL;
+            }
+        }
+    }
+
   /* If we have the page, then clean it up. */
-  if (formatted_page)
-    clean_manpage (formatted_page);
+  clean_manpage (formatted_page);
 
   return formatted_page;
 }
