@@ -1,5 +1,5 @@
 /* nodes.c -- how to get an Info file and node.
-   $Id: nodes.c 6014 2015-01-01 19:32:00Z karl $
+   $Id: nodes.c 6204 2015-04-06 13:47:43Z gavin $
 
    Copyright 1993, 1998, 1999, 2000, 2002, 2003, 2004, 2006, 2007,
    2008, 2009, 2011, 2012, 2013, 2014, 2015 Free Software Foundation, Inc.
@@ -1069,11 +1069,8 @@ info_get_node_of_file_buffer (FILE_BUFFER *file_buffer, char *nodename)
       node->nodelen = file_buffer->filesize;
       node->body_start = 0;
     }
-  /* If this is the "main" info file, it might contain a tags table.  Search
-     the tags table for an entry which matches the node that we want.  If
-     there is a tags table, get the file which contains this node, but don't
-     bother building a node list for it. */
-  else if (file_buffer->tags)
+  /* Search the tags table for an entry which matches the node that we want. */
+  else
     {
       TAG *tag;
       int i;
