@@ -1,5 +1,5 @@
 #! /bin/sh
-# $Id: regenerate_cmd_tests.sh 6139 2015-02-22 22:53:33Z karl $
+# $Id: regenerate_cmd_tests.sh 6197 2015-03-29 19:59:32Z pertusus $
 # Use information from test driving files to regenerate test scripts
 # that run only one test, and file lists to be used in Makefiles.
 #
@@ -25,6 +25,8 @@ test -d $test_scripts_dir || mkdir $test_scripts_dir
 dir=`echo $0 | sed 's,/[^/]*$,,'`
 outfile=$1
 shift
+destdir=$1
+shift
 
 while test z"$1" = 'z-base' -o z"$1" = 'z-long' -o z"$1" = 'z-tex_html'; do
   if test z"$1" = 'z-base'; then
@@ -43,7 +45,7 @@ done
 
 
 (
-cd "$dir/../tests" || exit 1
+cd "$dir/../tests/$destdir" || exit 1
 
 test_driving_files='test_driving_files_generated_list ='
 one_test_files='one_test_files_generated_list = '
@@ -70,7 +72,14 @@ for test_dir in $test_dirs; do
       name="texi_${basename}"
       arg="texi ${basename}.texi"
     fi
-    one_test_file="$test_scripts_dir/${test_dir}_$name.sh"
+    if test "z${test_dir}" = 'z.'; then
+      name_prepended=${destdir}_
+      relative_command_dir='/..'
+    else
+      name_prepended=${test_dir}_
+      relative_command_dir=
+    fi
+    one_test_file="$test_scripts_dir/${name_prepended}$name.sh"
     one_test_files="$one_test_files \\
      $one_test_file"
     echo '#! /bin/sh
@@ -116,13 +125,12 @@ name='$name'
 "'[ -d "$dir" ] || mkdir $dir
 
 srcdir_test=$dir; export srcdir_test;
-cd "$dir" || exit 99
-../"$srcdir"/"$command" -dir $dir $arg
+"$srcdir"'"$relative_command_dir"'/"$command" -dir $dir $arg
 exit_status=$?
-cat $one_test_logs_dir/$name.log
-if test -f $diffs_dir/$name.diff; then
+cat $dir/$one_test_logs_dir/$name.log
+if test -f $dir/$diffs_dir/$name.diff; then
   echo 
-  cat $diffs_dir/$name.diff
+  cat $dir/$diffs_dir/$name.diff
 fi
 exit $exit_status
 ' >> $one_test_file
